@@ -10,7 +10,7 @@ extern QString strLogfile;
 
 MainWindow::MainWindow(QObject *parent /*= 0*/)
 : QObject(parent)
-, gvApi (true, this)
+, gvApi (false, this)
 , bIsLoggedIn (false)
 , oContacts (this)
 , oInbox (gvApi, this)
@@ -210,6 +210,10 @@ MainWindow::checkParams ()
             qWarning ("Ini file does not contain the mq topic");
             cout << "Enter topic:";
             in >> m_strMqTopic;
+            if (m_strMqTopic.startsWith ('-')) {
+                qWarning ("Using gv_notify as topic instead");
+                m_strMqTopic = "gv_notify";
+            }
             settings.setValue ("mqtopic", m_strMqTopic);
         } else {
             m_strMqTopic = settings.value ("mqtopic").toString ();
@@ -356,8 +360,8 @@ MainWindow::doLogin ()
 
         //loadCookies ();
 
-        bOk = connect(token, SIGNAL(completed(AsyncTaskToken*)),
-                      this , SLOT(loginCompleted(AsyncTaskToken*)));
+        bOk = connect(token, SIGNAL(completed()),
+                      this , SLOT(loginCompleted()));
 
         token->inParams["user"] = strUser;
         token->inParams["pass"] = strPass;
@@ -383,17 +387,16 @@ MainWindow::doLogin ()
         strUser.clear ();
         strPass.clear ();
 
-        logoutCompleted (NULL);
         qApp->quit ();
     }
 }//MainWindow::doLogin
 
 void
-MainWindow::loginCompleted (AsyncTaskToken *token)
+MainWindow::loginCompleted()
 {
-    if (!token || (token->status != ATTS_SUCCESS)) {
-        logoutCompleted (NULL);
+    AsyncTaskToken *token = (AsyncTaskToken *) QObject::sender ();
 
+    if (!token || (token->status != ATTS_SUCCESS)) {
         Q_CRIT("User login failed");
         qApp->quit ();
     } else {
@@ -423,8 +426,7 @@ MainWindow::loginCompleted (AsyncTaskToken *token)
 
         //saveCookies ();
 
-        oContacts.setUserPass (strUser, strCPass);
-        oContacts.loginSuccess ();
+        oContacts.login (strUser, strCPass);
         oInbox.loginSuccess ();
 
         QTimer::singleShot (100, this, SLOT(doWork ()));
@@ -439,8 +441,8 @@ void
 MainWindow::doLogout ()
 {
     AsyncTaskToken *token = new AsyncTaskToken(this);
-    connect (token, SIGNAL(completed(AsyncTaskToken*)),
-             this, SLOT(logoutCompleted(AsyncTaskToken*)));
+    connect (token, SIGNAL(completed()),
+             this, SLOT(logoutCompleted()));
 
     if (!gvApi.logout (token)) {
         token->deleteLater ();
@@ -449,16 +451,18 @@ MainWindow::doLogout ()
 }//MainWindow::doLogout
 
 void
-MainWindow::logoutCompleted (AsyncTaskToken *token)
+MainWindow::logoutCompleted ()
 {
+    AsyncTaskToken *token = (AsyncTaskToken *) QObject::sender ();
+
     // This clears out the table and the view as well
-    oContacts.loggedOut ();
+    oContacts.logout ();
     oInbox.loggedOut ();
 
     bIsLoggedIn = false;
 
     if (token) {
-        delete token;
+        token->deleteLater ();
     }
 }//MainWindow::logoutCompleted
 
@@ -473,11 +477,14 @@ MainWindow::onTwoStepAuthentication(AsyncTaskToken *token)
     cout << "Enter PIN:";
     in >> strPIN;
 
-    token->inParams["user_pin"] = strPIN;
-
-    tfaRequired = true;
-
-    gvApi.resumeTFALogin (token);
+    if (strPIN.startsWith ('-')) {
+        qWarning ("Requesting GV Api to call you:");
+        gvApi.resumeTFAAltLogin (token);
+    } else {
+        token->inParams["user_pin"] = strPIN;
+        tfaRequired = true;
+        gvApi.resumeTFALogin (token);
+    }
 }//MainWindow::onTwoStepAuthentication
 
 void
