@@ -311,12 +311,6 @@ QmlMainWindow::initQmlObjects()
         if (NULL == mainPageStack) {
             break;
         }
-        connect(mainPageStack, SIGNAL(sigShowContact(QString)),
-                &oContacts, SLOT(getContactInfoAndModel(QString)));
-        connect(mainPageStack, SIGNAL(sigRefreshContacts()),
-                &oContacts, SLOT(refreshLatest()));
-        connect(mainPageStack, SIGNAL(sigRefreshContactsFull()),
-                &oContacts, SLOT(refreshFull()));
 
         mainTabGroup = getQMLObject ("MainTabGroup");
         if (NULL == mainTabGroup) {
