@@ -26,12 +26,11 @@ CQmlViewer *
 createQmlViewer()
 {
     return new CQmlViewer;
-}
+}//createQmlViewer
 
 CQmlViewer::CQmlViewer()
-: m_view(NULL)
+: m_view(SailfishApp::createView())
 {
-    m_view = SailfishApp::createView();
     if (NULL == m_view) {
         Q_WARN("Failed to create view");
     }
