@@ -148,6 +148,6 @@ protected:
 };
 
 QCoreApplication *
-createAppObject(int argc, char *argv[]);
+createAppObject(int &argc, char *argv[]);
 
 #endif // MAINWINDOW_H
