@@ -22,14 +22,16 @@ Contact: yuvraaj@gmail.com
 #ifndef PLATFORMSPECIFIC_H
 #define PLATFORMSPECIFIC_H
 
-#define UNKNOWN_CONTACT_QRC_PATH ":/unknown_contact.png"
-
 #include <QtGui>
 
+#define UNKNOWN_CONTACT_QRC_PATH ":/unknown_contact.png"
+
 #if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
 #include <QtWidgets>
+#include <QtWebKitWidgets/QWebView>
 #define PHONON_ENABLED 0
 #else
+#include <QtWebKit/QtWebKit>
 #define PHONON_ENABLED 1
 #endif
 
